@@ -49,6 +49,7 @@ typedef struct
   int   height;
   int   num_framerates;
   CheeseFramerate *framerates;
+  CheeseFramerate highest_framerate;
 } CheeseVideoFormat;
 
 typedef struct
@@ -59,6 +60,9 @@ typedef struct
   char *product_name;
   int   num_video_formats;
   GArray *video_formats;
+
+  /* Hash table for resolution based lookup of video_formats */
+  GHashTable *supported_resolutions;
 } CheeseWebcamDevice;
 
 typedef enum
